[Fedora-livecd-list] 2 commits - tools/livecd-iso-to-disk.sh

Brian C. Lane bcl at fedoraproject.org
Wed Mar 23 22:34:25 UTC 2011


 tools/livecd-iso-to-disk.sh |   15 +++++++--------
 1 file changed, 7 insertions(+), 8 deletions(-)

New commits:
commit 13bf748e61c44980d138b2046f5e46b7acf48cd2
Author: Brian C. Lane <bcl at redhat.com>
Date:   Wed Mar 23 14:06:25 2011 -0700

    Images go into $SYSLINUXPATH
    
    Now that syslinux version check is fixed they end up in the correct
    place.

diff --git a/tools/livecd-iso-to-disk.sh b/tools/livecd-iso-to-disk.sh
index 088188b..b37d9f2 100755
--- a/tools/livecd-iso-to-disk.sh
+++ b/tools/livecd-iso-to-disk.sh
@@ -828,7 +828,7 @@ if [ "$overlaysizemb" -gt 0 ]; then
     fi
     LABEL=$(/sbin/blkid -s LABEL -o value $TGTDEV)
     if [[ "$LABEL" =~ ( ) ]]; then
-        echo "The LABEL($LABEL) on $TGTDEV has spaces in it, which not work with the overlay"
+        echo "The LABEL($LABEL) on $TGTDEV has spaces in it, which do not work with the overlay"
         echo "You can re-format or use dosfslabel/e2fslabel to change it"
         exitclean
     fi




More information about the livecd mailing list
diff --git a/tools/livecd-iso-to-disk.sh b/tools/livecd-iso-to-disk.sh
index b37d9f2..5261aab 100755
--- a/tools/livecd-iso-to-disk.sh
+++ b/tools/livecd-iso-to-disk.sh
@@ -1136,8 +1136,8 @@ if [ "$srctype" = "installer" ]; then
     sed -i -e "s;initrd=initrd.img;initrd=initrd.img ${LANG:+LANG=$LANG} repo=hd:$TGTLABEL:/;g" $BOOTCONFIG
     sed -i -e "s;stage2=\S*;;g" $BOOTCONFIG
     if [ -n "$efi" ]; then
-        # Images are in / now
-        sed -i -e "s;images/pxeboot/;;g" -e "s;vmlinuz;vmlinuz ${LANG:+LANG=$LANG} repo=hd:$TGTLABEL:/;g" $BOOTCONFIG_EFI
+        # Images are in $SYSLINUXPATH now
+        sed -i -e "s;/images/pxeboot/;/$SYSLINUXPATH/;g" -e "s;vmlinuz;vmlinuz ${LANG:+LANG=$LANG} repo=hd:$TGTLABEL:/;g" $BOOTCONFIG_EFI
     fi
 fi
 
@@ -1148,11 +1148,10 @@ if [ "$srctype" = "netinst" ]; then
     else
         # The initrd has everything, so no stage2
         sed -i -e "s;stage2=\S*;;g" $BOOTCONFIG
-
-        if [ -n "$efi" ]; then
-            # Images are in / now
-            sed -ie "s;images/pxeboot/;;g" $BOOTCONFIG_EFI
-        fi
+    fi
+    if [ -n "$efi" ]; then
+        # Images are in $SYSLINUXPATH now
+        sed -ie "s;/images/pxeboot/;/$SYSLINUXPATH/;g" $BOOTCONFIG_EFI
     fi
 fi
 


commit 731b1adb6a2e48299f193af5637d2e3d7c45dfec
Author: Brian C. Lane <bcl at redhat.com>
Date:   Wed Mar 23 15:33:06 2011 -0700

    fix typo
